$font-color:     #333333 !default;
$quiet-color:    lighten($font-color, 20%) !default;
$loud-color:     darken($font-color, 13.33%) !default;
$header-color:   darken($font-color, 6.67%) !default;
$alt-text-color: #666666 !default;
$blueprint-background-color: #eeeeee !default;
$blueprint-border-color: #ddd !default;

$link-color:         #06c                  !default;
$link-hover-color:   #09f                  !default;
$link-focus-color:   $link-hover-color     !default;
$link-active-color:  lighten(adjust-hue($link-color, 75deg), 10%) !default;
$link-visited-color: darken($link-color, 10%) !default;

$feedback-border-color: #dddddd !default;
$success-color:         #264409 !default;
$success-bg-color:      #e6efc2 !default;
$success-border-color:  #c6d880 !default;
$notice-color:          #514721 !default;
$notice-bg-color:       #fff6bf !default;
$notice-border-color:   #ffd324 !default;
$info-color:            #205791 !default;
$info-bg-color:         #d5edf8 !default;
$info-border-color:     #92cae4 !default;
$error-color:           #8a1f11 !default;
$error-bg-color:        #fbe3e4 !default;
$error-border-color:    #fbc2c4 !default;

$highlight-color:        yellow !default;
$added-color:             white !default;
$added-bg-color:        #006600 !default;
$removed-color:           white !default;
$removed-bg-color:      #990000 !default;

$blueprint-table-header-color: #c3d9ff !default;
$blueprint-table-stripe-color: #e5ecf9 !default;
