@import url(helpers.scss);

@mixin blueprint-utilities {

  .clear {
        clear: both; }

  .nowrap {
        @include nowrap; }

  .clearfix {
        @include clearfix; }

  .small {
        font-size: 0.8em;
        margin-bottom: 1.875em;
        line-height: 1.875em; }

  .large {
        font-size: 1.2em;
        line-height: 2.5em;
        margin-bottom: 1.25em; }

  .first {
        margin-left: 0;
        padding-left: 0; }

  .last {
        margin-right: 0;
        padding-right: 0; }

  .top {
        margin-top: 0;
        padding-top: 0; }

  .bottom {
        margin-bottom: 0;
        padding-bottom: 0; } }
