@charset "UTF-8";
@import "shared";

// Cross-browser support for @font-face. Supports IE, Gecko, Webkit, Opera.
//
// * $name is required, arbitrary, and what you will use in font stacks.
// * $font-files is required using font-files('relative/location', 'format').
//   for best results use this order: woff, opentype/truetype, svg
// * $eot is required by IE, and is a relative location of the eot file.
// * For android 2.2 Compatiblity, please ensure that your web page has
//   a meta viewport tag.
// * To support iOS < 4.2, an SVG file must be provided
//
// If you need to generate other formats check out the Font Squirrel
// [font generator](http://www.fontsquirrel.com/fontface/generator)

@mixin font-face($name, $font-files, $eot: false) {
  @font-face {
    font-family: quote($name);
    @if $eot { src: font-url($eot); }
    src: local("☺"), $font-files; 
  }
  @media screen and (max-device-width: 480px) {
    @font-face {
      font-family: quote($name);   
      src: $font-files;
    }
  }
 
}

// EXAMPLE
// +font-face("this name", font-files("this.woff", "woff", "this.otf", "opentype"), "this.eot")
//
// will generate:
//
//   @font-face { 
//     font-family: 'this name'; 
//     src: url('fonts/this.eot'); 
//     src: local("☺"),
//       url('fonts/this.otf') format('woff'), 
//       url('fonts/this.woff') format('opentype'); 
//   }
