/* ============================== */
/* Zeta import: 'zeta://blueprint/all.scss' */
/* From: 'None' */
/* Blueprint Reset */

html, body {
	margin: 0;
	padding: 0;
	border: 0;
	vertical-align: baseline;
	font-weight: inherit;
	font-style: inherit;
	font-size: 100%;
	font-family: inherit}

html {
	font-size: 100.01%}

div, span, object, iframe, h1, h2, h3, h4, h5, h6, p, pre, a, abbr, acronym, address, code, del, dfn, em, img, dl, dt, dd, ol, ul, li, fieldset, form, label, legend, caption, tbody, tfoot, thead, tr {
	margin: 0;
	padding: 0;
	border: 0;
	vertical-align: baseline;
	font-weight: inherit;
	font-style: inherit;
	font-size: 100%;
	font-family: inherit}

blockquote, q {
	margin: 0;
	padding: 0;
	border: 0;
	quotes: '' '';
	vertical-align: baseline;
	font-weight: inherit;
	font-style: inherit;
	font-size: 100%;
	font-family: inherit}

blockquote:before, blockquote:after, q:before, q:after {
	content: ''}

th, td, caption {
	margin: 0;
	padding: 0;
	border: 0;
	vertical-align: baseline;
	vertical-align: middle;
	text-align: left;
	font-weight: normal;
	font-weight: inherit;
	font-style: inherit;
	font-size: 100%;
	font-family: inherit}

table {
	margin: 0;
	padding: 0;
	border: 0;
	border-collapse: separate;
	border-spacing: 0;
	vertical-align: baseline;
	vertical-align: middle;
	font-weight: inherit;
	font-style: inherit;
	font-size: 100%;
	font-family: inherit}

a img {
	border: none}
/* Blueprint Typography */

body {
	color: #444;
	line-height: 1.5;
	font-size: .75px;
	font-family: 'Helvetica Neue', Arial, Helvetica, sans-serif}

h1, h2, h3, h4, h5, h6 {
	color: #323232;
	font-weight: normal}

h1 img, h2 img, h3 img, h4 img, h5 img, h6 img {
	margin: 0}

h1 {
	margin-bottom: .5em;
	line-height: 1;
	font-size: 3em}

h2 {
	margin-bottom: .75em;
	font-size: 2em}

h3 {
	margin-bottom: 1em;
	line-height: 1;
	font-size: 1.5em}

h4 {
	margin-bottom: 1.25em;
	line-height: 1.25;
	font-size: 1.2em}

h5 {
	margin-bottom: 1.5em;
	font-weight: bold;
	font-size: 1em}

h6 {
	font-weight: bold;
	font-size: 1em}

p {
	margin: 0 0 1.5em}

p img.left {
	float: left;
	display: inline;
	margin: 1.5em 1.5em 1.5em 0;
	padding: 0}

p img.right {
	float: right;
	display: inline;
	margin: 1.5em 0 1.5em 1.5em;
	padding: 0}

a {
	color: #06c;
	text-decoration: underline}

a:visited {
	color: #004c99}

a:focus {
	color: #09f}

a:hover {
	color: #09f}

a:active {
	color: #bf00ff}

blockquote {
	margin: 1.5em;
	color: #666;
	font-style: italic}

strong {
	font-weight: bold}

em {
	font-style: italic}

dfn {
	font-weight: bold;
	font-style: italic}

sup, sub {
	line-height: 0}

abbr, acronym {
	border-bottom: 1px dotted #666}

address {
	margin: 0 0 1.5em;
	font-style: italic}

del {
	color: #666}

pre {
	margin: 1.5em 0;
	white-space: pre}

pre, code, tt {
	line-height: 1.5;
	font: 1em 'andale mono', 'lucida console', monospace}

li ul, li ol {
	margin: 0}

ul, ol {
	margin: 0 1.5em 1.5em 0;
	padding-left: 3.333em}

ul {
	list-style-type: disc}

ol {
	list-style-type: decimal}

dl {
	margin: 0 0 1.5em 0}

dl dt {
	font-weight: bold}

dd {
	margin-left: 1.5em}

table {
	margin-bottom: 1.4em;
	width: 100%}

th {
	font-weight: bold}

thead th {
	background: #c3d9ff}

th, td, caption {
	padding: 4px 10px 4px 5px}

tr.even td {
	background: #e5ecf9}

tfoot {
	font-style: italic}

caption {
	background: #eee}

.quiet {
	color: #777}

.loud {
	color: #222}
/* Blueprint utilities */

.clear {
	clear: both}

.nowrap {
	white-space: nowrap}

.clearfix {
	overflow: hidden;
	zoom: 1}

.small {
	margin-bottom: 1.875em;
	line-height: 1.875em;
	font-size: .8em}

.large {
	margin-bottom: 1.25em;
	line-height: 2.5em;
	font-size: 1.2em}

.first {
	margin-left: 0;
	padding-left: 0}

.last {
	margin-right: 0;
	padding-right: 0}

.top {
	margin-top: 0;
	padding-top: 0}

.bottom {
	margin-bottom: 0;
	padding-bottom: 0}
/* Blueprint form */

label {
	font-weight: bold}

fieldset {
	margin: 0 0 1.5em 0;
	padding: 1.4em}

legend {
	font-weight: bold;
	font-size: 1.2em}

input.text, input.title, input[type=email], input[type=text], input[type=password] {
	margin: .5em 0;
	padding: 5px;
	background-color: white}

input.title {
	font-size: 1.5em}

input[type=checkbox], input.checkbox, input[type=radio], input.radio {
	position: relative;
	top: .25em}

textarea {
	margin: .5em 0;
	padding: 5px}

select {
	margin: .5em 0}

fieldset {
	border: 1px solid #ccc}

input.text, input.title, input[type=email], input[type=text], input[type=password], textarea, select {
	border: 1px solid #bbb}

input.text:focus, input.title:focus, input[type=email]:focus, input[type=text]:focus, input[type=password]:focus, textarea:focus, select:focus {
	border: 1px solid #666}

input.text, input.title, input[type=email], input[type=text], input[type=password] {
	width: 300px}

textarea {
	width: 390px;
	height: 250px}
/* Blueprint interaction */

.error {
	margin-bottom: 1em;
	padding: .8em;
	border: 2px solid #ddd;
	border-color: #fbc2c4;
	background: #fbe3e4;
	color: #8a1f11}

.error a {
	color: #8a1f11}

.notice {
	margin-bottom: 1em;
	padding: .8em;
	border: 2px solid #ddd;
	border-color: #ffd324;
	background: #fff6bf;
	color: #514721}

.notice a {
	color: #514721}

.success {
	margin-bottom: 1em;
	padding: .8em;
	border: 2px solid #ddd;
	border-color: #c6d880;
	background: #e6efc2;
	color: #264409}

.success a {
	color: #264409}

.hide {
	display: none}

.highlight {
	background: yellow}

.added {
	background: #060;
	color: white}

.removed {
	background: #900;
	color: white}
/* Blueprint grid */

.container {
	overflow: hidden;
	zoom: 1;
	margin: 0 auto;
	width: 950px}

.column, span-1, span-2, span-3, span-4, span-5, span-6, span-7, span-8, span-9, span-10, span-11, span-12, span-13, span-14, span-15, span-16, span-17, span-18, span-19, span-20, span-21, span-22, span-23, span-24 {
	float: left;
	display: inline;
	margin-right: 10px}

* html .column, * html span-1, * html span-2, * html span-3, * html span-4, * html span-5, * html span-6, * html span-7, * html span-8, * html span-9, * html span-10, * html span-11, * html span-12, * html span-13, * html span-14, * html span-15, * html span-16, * html span-17, * html span-18, * html span-19, * html span-20, * html span-21, * html span-22, * html span-23, * html span-24 {
	overflow-x: hidden}

.last, div.last {
	margin-right: 0}

.span-1 {
	width: 30px}

input.span-1, textarea.span-1, select.span-1 {
	width: 30px !important}

.span-2 {
	width: 70px}

input.span-2, textarea.span-2, select.span-2 {
	width: 70px !important}

.span-3 {
	width: 110px}

input.span-3, textarea.span-3, select.span-3 {
	width: 110px !important}

.span-4 {
	width: 150px}

input.span-4, textarea.span-4, select.span-4 {
	width: 150px !important}

.span-5 {
	width: 190px}

input.span-5, textarea.span-5, select.span-5 {
	width: 190px !important}

.span-6 {
	width: 230px}

input.span-6, textarea.span-6, select.span-6 {
	width: 230px !important}

.span-7 {
	width: 270px}

input.span-7, textarea.span-7, select.span-7 {
	width: 270px !important}

.span-8 {
	width: 310px}

input.span-8, textarea.span-8, select.span-8 {
	width: 310px !important}

.span-9 {
	width: 350px}

input.span-9, textarea.span-9, select.span-9 {
	width: 350px !important}

.span-10 {
	width: 390px}

input.span-10, textarea.span-10, select.span-10 {
	width: 390px !important}

.span-11 {
	width: 430px}

input.span-11, textarea.span-11, select.span-11 {
	width: 430px !important}

.span-12 {
	width: 470px}

input.span-12, textarea.span-12, select.span-12 {
	width: 470px !important}

.span-13 {
	width: 510px}

input.span-13, textarea.span-13, select.span-13 {
	width: 510px !important}

.span-14 {
	width: 550px}

input.span-14, textarea.span-14, select.span-14 {
	width: 550px !important}

.span-15 {
	width: 590px}

input.span-15, textarea.span-15, select.span-15 {
	width: 590px !important}

.span-16 {
	width: 630px}

input.span-16, textarea.span-16, select.span-16 {
	width: 630px !important}

.span-17 {
	width: 670px}

input.span-17, textarea.span-17, select.span-17 {
	width: 670px !important}

.span-18 {
	width: 710px}

input.span-18, textarea.span-18, select.span-18 {
	width: 710px !important}

.span-19 {
	width: 750px}

input.span-19, textarea.span-19, select.span-19 {
	width: 750px !important}

.span-20 {
	width: 790px}

input.span-20, textarea.span-20, select.span-20 {
	width: 790px !important}

.span-21 {
	width: 830px}

input.span-21, textarea.span-21, select.span-21 {
	width: 830px !important}

.span-22 {
	width: 870px}

input.span-22, textarea.span-22, select.span-22 {
	width: 870px !important}

.span-23 {
	width: 910px}

input.span-23, textarea.span-23, select.span-23 {
	width: 910px !important}

.span-24 {
	width: 950px}

input.span-24, textarea.span-24, select.span-24 {
	width: 950px !important}

.span-24 {
	margin: 0}

.push-1 {
	margin: 0 -40px 1.5em 40px}

.pull-1 {
	margin-left: -40px}

.append-1 {
	padding-right: 40px}

.prepend-1 {
	padding-left: 40px}

.push-2 {
	margin: 0 -80px 1.5em 80px}

.pull-2 {
	margin-left: -80px}

.append-2 {
	padding-right: 80px}

.prepend-2 {
	padding-left: 80px}

.push-3 {
	margin: 0 -120px 1.5em 120px}

.pull-3 {
	margin-left: -120px}

.append-3 {
	padding-right: 120px}

.prepend-3 {
	padding-left: 120px}

.push-4 {
	margin: 0 -160px 1.5em 160px}

.pull-4 {
	margin-left: -160px}

.append-4 {
	padding-right: 160px}

.prepend-4 {
	padding-left: 160px}

.push-5 {
	margin: 0 -200px 1.5em 200px}

.pull-5 {
	margin-left: -200px}

.append-5 {
	padding-right: 200px}

.prepend-5 {
	padding-left: 200px}

.push-6 {
	margin: 0 -240px 1.5em 240px}

.pull-6 {
	margin-left: -240px}

.append-6 {
	padding-right: 240px}

.prepend-6 {
	padding-left: 240px}

.push-7 {
	margin: 0 -280px 1.5em 280px}

.pull-7 {
	margin-left: -280px}

.append-7 {
	padding-right: 280px}

.prepend-7 {
	padding-left: 280px}

.push-8 {
	margin: 0 -320px 1.5em 320px}

.pull-8 {
	margin-left: -320px}

.append-8 {
	padding-right: 320px}

.prepend-8 {
	padding-left: 320px}

.push-9 {
	margin: 0 -360px 1.5em 360px}

.pull-9 {
	margin-left: -360px}

.append-9 {
	padding-right: 360px}

.prepend-9 {
	padding-left: 360px}

.push-10 {
	margin: 0 -400px 1.5em 400px}

.pull-10 {
	margin-left: -400px}

.append-10 {
	padding-right: 400px}

.prepend-10 {
	padding-left: 400px}

.push-11 {
	margin: 0 -440px 1.5em 440px}

.pull-11 {
	margin-left: -440px}

.append-11 {
	padding-right: 440px}

.prepend-11 {
	padding-left: 440px}

.push-12 {
	margin: 0 -480px 1.5em 480px}

.pull-12 {
	margin-left: -480px}

.append-12 {
	padding-right: 480px}

.prepend-12 {
	padding-left: 480px}

.push-13 {
	margin: 0 -520px 1.5em 520px}

.pull-13 {
	margin-left: -520px}

.append-13 {
	padding-right: 520px}

.prepend-13 {
	padding-left: 520px}

.push-14 {
	margin: 0 -560px 1.5em 560px}

.pull-14 {
	margin-left: -560px}

.append-14 {
	padding-right: 560px}

.prepend-14 {
	padding-left: 560px}

.push-15 {
	margin: 0 -600px 1.5em 600px}

.pull-15 {
	margin-left: -600px}

.append-15 {
	padding-right: 600px}

.prepend-15 {
	padding-left: 600px}

.push-16 {
	margin: 0 -640px 1.5em 640px}

.pull-16 {
	margin-left: -640px}

.append-16 {
	padding-right: 640px}

.prepend-16 {
	padding-left: 640px}

.push-17 {
	margin: 0 -680px 1.5em 680px}

.pull-17 {
	margin-left: -680px}

.append-17 {
	padding-right: 680px}

.prepend-17 {
	padding-left: 680px}

.push-18 {
	margin: 0 -720px 1.5em 720px}

.pull-18 {
	margin-left: -720px}

.append-18 {
	padding-right: 720px}

.prepend-18 {
	padding-left: 720px}

.push-19 {
	margin: 0 -760px 1.5em 760px}

.pull-19 {
	margin-left: -760px}

.append-19 {
	padding-right: 760px}

.prepend-19 {
	padding-left: 760px}

.push-20 {
	margin: 0 -800px 1.5em 800px}

.pull-20 {
	margin-left: -800px}

.append-20 {
	padding-right: 800px}

.prepend-20 {
	padding-left: 800px}

.push-21 {
	margin: 0 -840px 1.5em 840px}

.pull-21 {
	margin-left: -840px}

.append-21 {
	padding-right: 840px}

.prepend-21 {
	padding-left: 840px}

.push-22 {
	margin: 0 -880px 1.5em 880px}

.pull-22 {
	margin-left: -880px}

.append-22 {
	padding-right: 880px}

.prepend-22 {
	padding-left: 880px}

.push-23 {
	margin: 0 -920px 1.5em 920px}

.pull-23 {
	margin-left: -920px}

.append-23 {
	padding-right: 920px}

.prepend-23 {
	padding-left: 920px}

.pull-1, .pull-2, .pull-3, .pull-4, .pull-5, .pull-6, .pull-7, .pull-8, .pull-9, .pull-10, .pull-11, .pull-12, .pull-13, .pull-14, .pull-15, .pull-16, .pull-17, .pull-18, .pull-19, .pull-20, .pull-21, .pull-22, .pull-23 {
	position: relative;
	float: left;
	display: inline}

.push-1, .push-2, .push-3, .push-4, .push-5, .push-6, .push-7, .push-8, .push-9, .push-10, .push-11, .push-12, .push-13, .push-14, .push-15, .push-16, .push-17, .push-18, .push-19, .push-20, .push-21, .push-22, .push-23 {
	position: relative;
	float: right;
	display: inline}

.prepend-top {
	margin-top: 1.5em}

.append-bottom {
	margin-bottom: 1.5em}


/* ============================== */
/* Zeta import: 'zeta://blueprint.css' */
/* From: 'zeta://blueprint/all.scss' */
/* 
Blueprint is a CSS framework. See: http://www.blueprintcss.org/ 
1.0
 */


