/*
 * print styles
 * inlined to avoid required HTTP connection www.phpied.com/delay-loading-your-print-css/
 */ 
@media print { 
* {
	-ms-filter: none !important;
	background: transparent !important;
	color: black !important;
	filter: none !important;
	text-shadow: none !important}

a, a:visited {
	color: #444 !important;
	text-decoration: underline}

a[href] :after {
	content: " (" attr(href) ")"}

abbr[title] :after {
	content: " (" attr(title) ")"}

.ir a:after, a[href^="javascript:"] :after, a[href^="#"] :after {
	content: ""}

pre, blockquote {
	border: 1px solid #999;
	page-break-inside: avoid}

thead {
	display: table-header-group}

tr, img {
	page-break-inside: avoid}

@page {
	margin: 0.5cm}

p, h2, h3 {
	orphans: 3;
	widows: 3}

h2, h3 {
	page-break-after: avoid}
}
